==> 3.0.5.tar.gz: lib/ui/molecules/pumaSlider.dart <==
import 'package:flutter/material.dart';

class PumaSlider extends StatefulWidget {
  final double value;
  final String labelPrefix;
  final String labelSuffix;
  final double min;
  final double max;
  final bool displayValue;
  final bool showThumb;
  final Color? valueColor;
  final void Function(double)? onChanged;
  final Color? color;
  final int? divisions;
  final bool disabled;

  const PumaSlider(
    this.value, {
    this.labelPrefix = "",
    this.labelSuffix = "",
    this.onChanged,
    this.color,
    this.displayValue = false,
    this.valueColor,
    this.showThumb = false,
    this.min = 0,
    this.max = 1,
    this.divisions,
    this.disabled = false,
  });

  @override
  _PumaSliderState createState() => _PumaSliderState();
}

class _PumaSliderState extends State<PumaSlider> {
  double value = 0;
  int division = 10;

  @override
  void initState() {
    super.initState();

    setState(() {
      value = widget.value;
      if (widget.divisions != null) {
        division = widget.divisions!;
      } else {
        int intervals = widget.max.toInt() - widget.min.toInt();
        if (intervals > 0) {
          division = intervals;
        }
      }
    });
  }

  String stringValue() {
    String sVal = (value).toInt().toString();
    String pre = widget.labelPrefix;
    String suf = widget.labelSuffix;

    return "$pre$sVal$suf";
  }

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: const EdgeInsets.only(top: 16.0),
      child: Column(
        children: [
          if (widget.displayValue)
            Text(
              "${value.toInt()}",
              style: Theme.of(context)
                  .textTheme
                  .headline3!
                  .merge(TextStyle(color: widget.valueColor)),
            ),
          Slider(
            value: value,
            min: widget.min,
            max: widget.max,
            divisions: division,
            activeColor: widget.color ?? Theme.of(context).primaryColor,
            inactiveColor: Colors.black.withAlpha(100),
            label: widget.showThumb ? stringValue() : null,
            onChanged: (double val) {
              if (widget.disabled) return;
              setState(() {
                value = val;
              });
            },
            onChangeEnd: (double val) {
              if (widget.onChanged != null) {
                widget.onChanged!(val);
              }
            },
          ),
        ],
      ),
    );
  }
}

==> 3.0.6.tar.gz: lib/ui/molecules/pumaSlider.dart <==
import 'package:flutter/material.dart';

class PumaSlider extends StatefulWidget {
  final double value;
  final String labelPrefix;
  final String labelSuffix;
  final double min;
  final double max;
  final bool displayValue;
  final bool showThumb;
  final Color? valueColor;
  final void Function(double)? onChanged;
  final Color? color;
  final int? divisions;
  final bool disabled;
  final int valueMultiplier;

  const PumaSlider(
    this.value, {
    this.labelPrefix = "",
    this.labelSuffix = "",
    this.onChanged,
    this.color,
    this.displayValue = false,
    this.valueColor,
    this.showThumb = false,
    this.min = 0,
    this.max = 1,
    this.divisions,
    this.disabled = false,
    this.valueMultiplier = 1,
  });

  @override
  _PumaSliderState createState() => _PumaSliderState();
}

class _PumaSliderState extends State<PumaSlider> {
  double value = 0;
  int division = 10;

  @override
  void initState() {
    super.initState();

    setState(() {
      value = widget.value;
      if (widget.divisions != null) {
        division = widget.divisions!;
      } else {
        int intervals = widget.max.toInt() - widget.min.toInt();
        if (intervals > 0) {
          division = intervals;
        }
      }
    });
  }

  String stringValue() {
    String sVal = (value * widget.valueMultiplier).toInt().toString();
    String pre = widget.labelPrefix;
    String suf = widget.labelSuffix;

    return "$pre$sVal$suf";
  }

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: const EdgeInsets.only(top: 16.0),
      child: Column(
        children: [
          if (widget.displayValue)
            Text(
              "${value.toInt()}",
              style: Theme.of(context)
                  .textTheme
                  .headline3!
                  .merge(TextStyle(color: widget.valueColor)),
            ),
          SliderTheme(
            data: SliderTheme.of(context).copyWith(
              valueIndicatorColor: widget.color,
              valueIndicatorShape: PaddleSliderValueIndicatorShape(),
            ),
            child: Slider(
              value: value,
              min: widget.min,
              max: widget.max,
              divisions: division,
              activeColor: widget.color ?? Theme.of(context).primaryColor,
              inactiveColor: Colors.black.withAlpha(100),
              label: widget.showThumb ? stringValue() : null,
              onChanged: (double val) {
                if (widget.disabled) return;
                setState(() {
                  value = val;
                });
              },
              onChangeEnd: (double val) {
                if (widget.onChanged != null) {
                  widget.onChanged!(val);
                }
              },
            ),
          ),
        ],
      ),
    );
  }
}
